@@ -1,5 +1,5 @@
 #!/usr/bin/env bash
-# Copyright (C) 2022 The Qt Company Ltd.
+# Copyright (C) 2025 The Qt Company Ltd.
 # SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 # This script install Android sdk and ndk.
@@ -24,14 +24,21 @@ basePath="http://ci-files01-hki.ci.qt.io/input/android"
 
 toolsVersion="2.1"
 toolsFile="commandlinetools-linux-6609375_latest.zip"
-ndkVersionLatest="r27c"
-ndkVersionDefault=$ndkVersionLatest
-sdkBuildToolsVersion="35.0.1"
-sdkApiLevel="android-35"
-
+sdkBuildToolsVersion="36.0.0"
+sdkApiLevel="android-36"
 toolsSha1="9172381ff070ee2a416723c1989770cf4b0d1076"
+
+ndkVersionLatest="r27c"
 ndkSha1Latest="090e8083a715fdb1a3e402d0763c388abb03fb4e"
-ndkSha1Default=$ndkSha1Latest
+
+# Non-latest (but still supported by the qt/qt5 branch) NDKs are installed for nightly targets in:
+# coin/platform_configs/nightly_android.yaml
+
+ndkVersionNightly1=$ndkVersionLatest  # Same version = skip NDK install for nightly
+ndkSha1Nightly1=$ndkSha1Latest
+
+ndkVersionNightly2=$ndkVersionLatest
+ndkSha1Nightly2=$ndkSha1Latest
 
 # Android Automotive max SDK level image
 sdkApiLevelAutomotiveMax="android-34"
@@ -69,17 +76,22 @@ function InstallNdk() {
     androidNdkRoot="${targetFolder}/${zipBase}"
 }
 
-InstallNdk $ndkVersionDefault $ndkSha1Default
-SetEnvVar "ANDROID_NDK_ROOT_DEFAULT" "$androidNdkRoot"
-
-if [ "$ndkVersionDefault" != "$ndkVersionLatest" ]; then
-    InstallNdk $ndkVersionLatest $ndkSha1Latest
-fi
+InstallNdk $ndkVersionLatest $ndkSha1Latest
 SetEnvVar "ANDROID_NDK_ROOT_LATEST" "$androidNdkRoot"
 
+if [ "$ndkVersionNightly1" != "$ndkVersionLatest" ]; then
+    InstallNdk $ndkVersionNightly1 $ndkSha1Nightly1
+    SetEnvVar "ANDROID_NDK_ROOT_NIGHTLY1" "$androidNdkRoot"
+fi
+
+if [ "$ndkVersionNightly2" != "$ndkVersionLatest" ]; then
+    InstallNdk $ndkVersionNightly2 $ndkSha1Nightly2
+    SetEnvVar "ANDROID_NDK_ROOT_NIGHTLY2" "$androidNdkRoot"
+fi
+
 # To be used by vcpkg
-SetEnvVar "ANDROID_NDK_HOME" "$targetFolder/android-ndk-$ndkVersionDefault"
-export ANDROID_NDK_HOME="$targetFolder/android-ndk-$ndkVersionDefault"
+SetEnvVar "ANDROID_NDK_HOME" "$targetFolder/android-ndk-$ndkVersionLatest"
+export ANDROID_NDK_HOME="$targetFolder/android-ndk-$ndkVersionLatest"
 
 echo "Changing ownership of Android files."
 if uname -a |grep -q "el7"; then
@@ -146,7 +158,7 @@ echo "Download and unzip Android 9 System Image"
 minVersionFileName="x86-28_r08.zip"
 minVersionDestination="$sdkTargetFolder/system-images/android-28/google_apis/"
 minVersionFilePath="$minVersionDestination/$minVersionFileName"
-minVersionCiUrl="$basePath/system-images/google_apis/$minVersionFileName"
+minVersionCiUrl="$basePath/system_images/google_apis/$minVersionFileName"
 minVersionUrl="https://dl.google.com/android/repository/sys-img/google_apis/$minVersionFileName"
 minVersionSha1="41e3b854d7987a3d8b7500631dae1f1d32d3db4e"
 
@@ -157,18 +169,18 @@ echo "Unzipping the Android 9 to $minVersionDestination"
 sudo unzip -o -q "$minVersionFilePath" -d "$minVersionDestination"
 rm "$minVersionFilePath"
 
-echo "Download and unzip Android 15 System Image"
-maxVersionFileName="x86_64-35_r08.zip"
-maxVersionDestination="$sdkTargetFolder/system-images/android-35/google_apis/"
+echo "Download and unzip Android 16 System Image"
+maxVersionFileName="x86_64-36_r07.zip"
+maxVersionDestination="$sdkTargetFolder/system-images/android-36/google_apis/"
 maxVersionFilePath="$maxVersionDestination/$maxVersionFileName"
-maxVersionCiUrl="$basePath/system-images/google_apis/$maxVersionFileName"
+maxVersionCiUrl="$basePath/system_images/google_apis/$maxVersionFileName"
 maxVersionUrl="https://dl.google.com/android/repository/sys-img/google_apis/$maxVersionFileName"
-maxVersionSha1="d79169884cabc6680cb29d32c2112ad46c858c1b"
+maxVersionSha1="c6bf44bdcd885bb902b4ba752d111a073ad7a817"
 
 mkdir -p "$maxVersionDestination"
 DownloadURL "$maxVersionCiUrl" "$maxVersionUrl" "$maxVersionSha1" "$maxVersionFilePath"
 
-echo "Unzipping the Android 15 to $maxVersionDestination"
+echo "Unzipping the Android 16 to $maxVersionDestination"
 sudo unzip -o -q "$maxVersionFilePath" -d "$maxVersionDestination"
 rm "$maxVersionFilePath"
 
@@ -178,8 +190,8 @@ ls -l "$sdkTargetFolder"
 echo "no" | ./avdmanager create avd -n emulator_x86_api_28 -c 2048M -f \
     -k "system-images;android-28;google_apis;x86"
 
-echo "no" | ./avdmanager create avd -n emulator_x86_64_api_35 -c 2048M -f \
-    -k "system-images;android-35;google_apis;x86_64"
+echo "no" | ./avdmanager create avd -n emulator_x86_64_api_36 -c 2048M -f \
+    -k "system-images;android-36;google_apis;x86_64"
 
 echo "Install maximum supported SDK level image for Android Automotive $sdkApiLevelAutomotiveMax"
 DownloadURL "$androidAutomotiveMaxUrl" "$androidAutomotiveMaxUrl" "$androidAutomotiveMaxSha" \
@@ -210,7 +222,7 @@ cp -r "${scripts_dir_name}/android/gradle_project" /tmp/gradle_project
 cd /tmp/gradle_project
 # Get Gradle files from qtbase
 qtbaseGradleUrl="https://code.qt.io/cgit/qt/qtbase.git/plain/src/3rdparty/gradle"
-commit_sha="e5f79573fe2f21cf7bea8f63386f39bb18b351f0"
+commit_sha="5bc160bc8385f6a2e590ffb964d1d390c1ab4ce6"
 curl "$qtbaseGradleUrl/gradle.properties?h=$commit_sha" > gradle.properties
 curl "$qtbaseGradleUrl/gradlew?h=$commit_sha" > gradlew
 curl "$qtbaseGradleUrl/gradlew.bat?h=$commit_sha" > gradlew.bat
